==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/nl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Eenvoudige bestand viewer met diavertoning voor media bestanden",
    "Your browser does not support audio." : "Je browser ondersteunt geen audio.",
    "Error loading {name}" : "Fout bij laden van {name}",
    "Image saved" : "Afbeelding opgeslagen",
    "Unsaved changes" : "Niet opgeslagen veranderingen",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Je browser ondersteunt geen videos.",
    "Edit" : "Bewerk",
    "Open sidebar" : "Open zijbalk",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "There is no plugin available to display this file type" : "Er is geen plug-in beschikbaar om dit bestandstype weer te geven",
    "View" : "Bekijken",
    "Name" : "Naam",
    "Save" : "Opslaan",
    "Back" : "Terug",
    "Loading …" : "Laden …",
    "Reset" : "Herstellen",
    "All changes will be lost." : "Alle aanpassingen zullen verloren gaan.",
    "Are you sure you want to continue?" : "Weet je zeker dat je wilt doorgaan?",
    "Cancel" : "Annuleren",
    "Apply" : "Pas toe",
    "Warning" : "Waarschuwing",
    "Confirm" : "Bevestigen",
    "Undo" : "Ongedaan maken",
    "Redo" : "Opnieuw doen",
    "Show original image" : "Toon originele afbeelding",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Uitzoomen",
    "Toggle zoom menu" : "Toon/verberg zoommenu",
    "Adjust" : "Aanpassen",
    "Filters" : "Filters",
    "Draw" : "Tekenen",
    "Original" : "Origineel",
    "Custom" : "Maatwerk",
    "Landscape" : "Landschap",
    "Portrait" : "Portret",
    "Ellipse" : "Ovaal",
    "Arrow" : "Pijl",
    "Blur" : "Vervagen",
    "Brightness" : "Helderheid",
    "Contrast" : "Contrast",
    "Un-flip X" : "Ontspiegelen X",
    "Flip X" : "Spiegel X",
    "Un-flip Y" : "Spiegel Y",
    "Flip Y" : "Ontspiegel Y",
    "HSV" : "HSV",
    "Hue" : "Tint",
    "Saturation" : "Verzadiging",
    "Value" : "Waarden",
    "Image" : "Afbeelding",
    "+ Add image" : "+ Afbeelding toevoegen",
    "Line" : "Lijn",
    "Polygon" : "Veelhoek",
    "Rectangle" : "Rechthoek",
    "Corner Radius" : "Hoekradius",
    "Height in pixels" : "Hoogte in pixels",
    "Toggle ratio lock" : "In-/uitschakelen ratio vergrendeling",
    "Rotate" : "Draaien",
    "Text" : "Tekst",
    "Size" : "Omvang",
    "Line height" : "Regelhoogte",
    "Warmth" : "Warmte",
    "Shadow" : "Schaduw",
    "Opacity" : "Doorzichtigheid",
    "Position" : "Positie",
    "Stroke" : "Rand",
    "Extension" : "Extensie",
    "Name is required." : "Naam is verplicht",
    "Quality" : "Kwaliteit",
    "Saved image size (width x height)" : "Grootte van opgeslagen afbeelding (breedte x hoogte)",
    "Actual size (100%)" : "Ware grootte (100%)",
    "Fit size" : "Passend maken",
    "Menu" : "Menu",
    "Height" : "Lengte",
    "Continue" : "Doorgaan"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/nl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Eenvoudige bestand viewer met diavertoning voor media bestanden",
    "Your browser does not support audio." : "Je browser ondersteunt geen audio.",
    "Error loading {name}" : "Fout bij laden van {name}",
    "Cancel" : "Annuleren",
    "Image saved" : "Afbeelding opgeslagen",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Je browser ondersteunt geen videos.",
    "There is no plugin available to display this file type" : "Er is geen plug-in beschikbaar om dit bestandstype weer te geven",
    "Edit" : "Bewerk",
    "Open sidebar" : "Open zijbalk",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "View" : "Bekijken",
    "Name" : "Naam",
    "Save" : "Opslaan",
    "Save as" : "Opslaan als",
    "Back" : "Terug",
    "Loading …" : "Laden …",
    "Reset" : "Herstellen",
    "All changes will be lost." : "Alle aanpassingen zullen verloren gaan.",
    "Are you sure you want to continue?" : "Weet je zeker dat je wilt doorgaan?",
    "Apply" : "Pas toe",
    "Warning" : "Waarschuwing",
    "Confirm" : "Bevestigen",
    "Undo" : "Ongedaan maken",
    "Redo" : "Opnieuw doen",
    "Show original image" : "Toon originele afbeelding",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Uitzoomen",
    "Toggle zoom menu" : "Toon/verberg zoommenu",
    "Adjust" : "Aanpassen",
    "Filters" : "Filters",
    "Draw" : "Tekenen",
    "Original" : "Origineel",
    "Custom" : "Maatwerk",
    "Landscape" : "Landschap",
    "Portrait" : "Portret",
    "Ellipse" : "Ovaal",
    "Arrow" : "Pijl",
    "Blur" : "Vervagen",
    "Brightness" : "Helderheid",
    "Contrast" : "Contrast",
    "Un-flip X" : "Ontspiegelen X",
    "Flip X" : "Spiegel X",
    "Un-flip Y" : "Spiegel Y",
    "Flip Y" : "Ontspiegel Y",
    "HSV" : "HSV",
    "Hue" : "Tint",
    "Saturation" : "Verzadiging",
    "Value" : "Waarden",
    "Image" : "Afbeelding",
    "+ Add image" : "+ Afbeelding toevoegen",
    "Line" : "Lijn",
    "Polygon" : "Veelhoek",
    "Rectangle" : "Rechthoek",
    "Corner Radius" : "Hoekradius",
    "Height in pixels" : "Hoogte in pixels",
    "Toggle ratio lock" : "In-/uitschakelen ratio vergrendeling",
    "Rotate" : "Draaien",
    "Text" : "Tekst",
    "Size" : "Omvang",
    "Line height" : "Regelhoogte",
    "Warmth" : "Warmte",
    "Shadow" : "Schaduw",
    "Opacity" : "Doorzichtigheid",
    "Position" : "Positie",
    "Stroke" : "Rand",
    "Extension" : "Extensie",
    "Name is required." : "Naam is verplicht",
    "Quality" : "Kwaliteit",
    "Saved image size (width x height)" : "Grootte van opgeslagen afbeelding (breedte x hoogte)",
    "Actual size (100%)" : "Ware grootte (100%)",
    "Fit size" : "Passend maken",
    "Menu" : "Menu",
    "Height" : "Lengte"
},
"nplurals=2; plural=(n != 1);");
